summaryrefslogtreecommitdiffstats
path: root/mpeglib/lib/mpegplay/videoDecoder.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'mpeglib/lib/mpegplay/videoDecoder.cpp')
-rw-r--r--mpeglib/lib/mpegplay/videoDecoder.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/mpeglib/lib/mpegplay/videoDecoder.cpp b/mpeglib/lib/mpegplay/videoDecoder.cpp
index b7144291..427e06c2 100644
--- a/mpeglib/lib/mpegplay/videoDecoder.cpp
+++ b/mpeglib/lib/mpegplay/videoDecoder.cpp
@@ -69,7 +69,7 @@ VideoDecoder::~VideoDecoder() {
*
* mpegVidRsrc --
*
* Parses bit stream until MB_TQUANTUM number of
* macroblocks have been decoded or current slice or
* picture ends, whichever comes first. If the start
* of a frame is encountered, the frame is time stamped
@@ -204,8 +204,8 @@ int VideoDecoder::mpegVidRsrc(PictureArray* pictureArray) {
break;
}
- /* Parse next MB_TQUANTUM macroblocks. */
- for (i = 0; i < MB_TQUANTUM; i++) {
+ /* Parse next MB_QUANTUM macroblocks. */
+ for (i = 0; i < MB_QUANTUM; i++) {
/* Check to see if actually a startcode and not a macroblock. */
data=mpegVideoStream->showBits(23);
@@ -232,7 +232,7 @@ int VideoDecoder::mpegVidRsrc(PictureArray* pictureArray) {
}
}
data=mpegVideoStream->showBits(23);
/* Check if we just finished a picture on the MB_TQUANTUM macroblock */
if (data == 0x0) {
mpegVideoStream->next_start_code();
@@ -69,7 +69,7 @@ VideoDecoder::~VideoDecoder() {
* mpegVidRsrc --
*
- * Parses bit stream until MB_TQUANTUM number of
+ * Parses bit stream until MB_QUANTUM number of
* macroblocks have been decoded or current slice or
* picture ends, whichever comes first. If the start
@@ -232,7 +232,7 @@ int VideoDecoder::mpegVidRsrc(PictureArray* pictureArray) {
}
data=mpegVideoStream->showBits(23);
- /* Check if we just finished a picture on the MB_TQUANTUM macroblock */
+ /* Check if we just finished a picture on the MB_QUANTUM macroblock */
if (data == 0x0) {
mpegVideoStream->next_start_code();